@@ -1,4 +1,3 @@
-import tldextract
 from bs4 import BeautifulSoup
 
 from ..base_functions import *
@@ -13,13 +12,12 @@ class EromeCrawler():
         url_extract = tldextract.extract(str(url))
         base_domain = "{}.{}".format(url_extract.domain, url_extract.suffix)
         domain_obj = DomainItem(base_domain, {})
-        cookies = []
 
         log("Starting scrape of " + str(url), Fore.WHITE)
         logging.debug("Starting scrape of " + str(url))
 
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
 
@@ -46,4 +44,4 @@ class EromeCrawler():
         log("Finished scrape of " + str(url), Fore.WHITE)
         logging.debug("Finished scrape of " + str(url))
 
-        return domain_obj, cookies
+        return domain_obj
