@@ -1,4 +1,3 @@
-import tldextract
 from bs4 import BeautifulSoup
 
 from ..base_functions import *
@@ -13,7 +12,6 @@ class ShareXCrawler():
         url_extract = tldextract.extract(str(url))
         base_domain = "{}.{}".format(url_extract.domain, url_extract.suffix)
         domain_obj = DomainItem(base_domain, {})
-        cookies = []
 
         log("Starting scrape of " + str(url), Fore.WHITE)
         logging.debug("Starting scrape of " + str(url))
@@ -32,12 +30,12 @@ class ShareXCrawler():
         log("Finished scrape of " + str(url), Fore.WHITE)
         logging.debug("Finished scrape of " + str(url))
 
-        return domain_obj, cookies
+        return domain_obj
 
     async def get_albums(self, url, session):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
                 albums = soup.select("a[class='image-container --media']")
@@ -52,7 +50,7 @@ class ShareXCrawler():
     async def get_singular(self, url, session):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
                 link = URL(soup.select_one("input[id=embed-code-2]").get('value'))
@@ -67,7 +65,7 @@ class ShareXCrawler():
     async def get_sub_album_links(self, url, session, og_title):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
                 albums = soup.select("div[class=pad-content-listing] div")
@@ -84,7 +82,7 @@ class ShareXCrawler():
     async def parse_profile(self, url, session):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
                 title = soup.select_one("div[class=header] h1 strong").get_text()
@@ -105,7 +103,7 @@ class ShareXCrawler():
     async def get_list_links(self, url, session, title):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
                 if url.host == 'jpg.church':
@@ -130,7 +128,7 @@ class ShareXCrawler():
     async def parse(self, url, session, og_title=None):
         results = []
         try:
-            async with session.get(url) as response:
+            async with session.get(url, ssl=ssl_context) as response:
                 text = await response.text()
                 soup = BeautifulSoup(text, 'html.parser')
 
